import React from 'react';
import { Button } from '../buttons';

export type PaginationProps = {
  currentPage: number;
  totalPages: number;
  onPageChange: (page: number) => void;
  itemsPerPageInput: number;
  numItemsArrayReal: number;
  totalItems: number;
  arrangement?: 'vertical' | 'horizontal';
  className?: string;
};

export const Pagination: React.FC<PaginationProps> = ({
  currentPage,
  totalPages,
  onPageChange,
  itemsPerPageInput,
  numItemsArrayReal,
  totalItems,
  arrangement = 'horizontal',
  className = '',
}) => {
  const firstItem = (currentPage - 1) * itemsPerPageInput + 1;

  const goToPreviousPage = () => {
    if (currentPage > 1) {
      onPageChange(currentPage - 1);
    }
  };

  const goToNextPage = () => {
    if (currentPage < totalPages) {
      onPageChange(currentPage + 1);
    }
  };

  const backIcon = arrangement === 'vertical' ? 'icon-[ic--baseline-arrow-upward]' : 'icon-[ic--baseline-arrow-back]';
  const forwardIcon = arrangement === 'vertical' ? 'icon-[ic--baseline-arrow-downward]' : 'icon-[ic--baseline-arrow-forward]';

  return (
    <div
      className={`self-center table-pagination flex flex-col items-center py-2 gap-1.5 ${arrangement === 'vertical' ? 'flex-col' : 'flex-row'} ${className}`}
    >
      <div className="inline-block text-sm">
        <span className="font-semibold">{`${firstItem} - ${numItemsArrayReal}`}</span> of {totalItems}
      </div>
      <div className={`grid ${arrangement === 'vertical' ? 'grid-rows-3' : 'grid-cols-2'} gap-2`}>
        <Button
          size={'sm'}
          label="Previous"
          variant="outline"
          iconComponent={backIcon}
          onClick={goToPreviousPage}
          disabled={currentPage === 1}
        />
        <Button
          size={'sm'}
          label="Next"
          variant="outline"
          iconComponent={forwardIcon}
          iconPosition="trailing"
          onClick={goToNextPage}
          disabled={currentPage === totalPages || numItemsArrayReal === totalItems}
        />
      </div>
    </div>
  );
};
