import { useLexicalComposerContext } from '@lexical/react/LexicalComposerContext';
import { $getSelection, type BaseSelection } from 'lexical';
import { Input } from '@graphpolaris/shared/lib/components/inputs';
import { VariableNode, VariableType } from '../VariableNode';
import { useGraphQueryResult, useVisualization } from '@graphpolaris/shared/lib/data-access';

export const InsertVariablesPlugin = () => {
  const [editor] = useLexicalComposerContext();
  const { openVisualizationArray } = useVisualization();

  const visualizationOptions = openVisualizationArray.map((x) => x.name);

  const onChange = (value: string | number, type: VariableType) => {
    editor.update(() => {
      const selection = $getSelection() as BaseSelection;

      const node = new VariableNode(String(value), type);

      selection.insertNodes([node]);

      // TODO: enable drag and dropping nodes
    });
  };

  const result = useGraphQueryResult();

  const nodeTypes = Object.keys(result.metaData?.nodes.types || {});
  function optionsForType(type: string) {
    const typeObj = result.metaData?.nodes.types[type] ?? { attributes: null };

    if (!('attributes' in typeObj) || typeObj.attributes == null) {
      return [];
    }

    return Object.entries(typeObj.attributes)
      .map(([k, v]) => Object.keys(v).map((x) => `${k}_${x}`))
      .flat();
  }

  return (
    <>
      {nodeTypes.map((nodeType) => (
        <Input
          type="dropdown"
          label={`${nodeType} variable`}
          value=""
          options={optionsForType(nodeType)}
          onChange={(v) => onChange(v, VariableType.statistic)}
        />
      ))}
      {visualizationOptions.length > 0 ? (
        <Input
          type="dropdown"
          label={`Visualization`}
          value=""
          options={visualizationOptions}
          onChange={(v) => onChange(v, VariableType.visualization)}
        />
      ) : (
        ''
      )}
    </>
  );
};
