import { LegacyRef, useRef, useEffect, MutableRefObject } from 'react';
import { useLexicalComposerContext } from '@lexical/react/LexicalComposerContext';
import { FORMAT_TEXT_COMMAND } from 'lexical';
import { Button } from '../../buttons';
import { $generateHtmlFromNodes } from '@lexical/html';

export function PreviewPlugin({ contentEditable }: { contentEditable: MutableRefObject<HTMLDivElement | undefined> }): JSX.Element {
  const [editor] = useLexicalComposerContext();

  function updatePreview() {
    editor.read(() => {
      const html = $generateHtmlFromNodes(editor as any); // any needed to avoid excessive ts error
      const preview = document.querySelector('.editor + .preview');
      if (preview == null) return; // TODO: nope
      preview.innerHTML = html;
    });
  }

  const activeClasses = ['text-blue-600', 'bg-light', 'active'];

  function resetStyling(event: React.MouseEvent) {
    document.querySelectorAll('.toolbar-preview li button').forEach((btn) => btn.classList.remove('text-blue-600', 'bg-light'));
    const button = event.target as HTMLButtonElement;
    button.classList.add(...activeClasses);
  }

  function showPreview(event: React.MouseEvent) {
    resetStyling(event);

    const editor = contentEditable.current?.parentElement;
    if (editor == null) return;

    editor.classList.add('hidden');
    let preview = editor.parentElement?.querySelector('.editor + .preview');
    preview?.classList.remove('hidden');

    updatePreview();
  }

  function showEditor(event: React.MouseEvent) {
    resetStyling(event);

    const button = event.target as HTMLButtonElement;
    button.classList.add(...activeClasses);

    const editor = contentEditable.current?.parentElement;
    if (editor == null) return;

    editor.classList.remove('hidden');
    editor.querySelector('div').focus();

    let preview = editor.parentElement?.querySelector('.editor + .preview');
    if (preview == null) return;
    preview.classList.add('hidden');
  }

  return (
    <ul
      className="toolbar-preview flex flex-wrap text-sm font-medium text-center text-gray-500 dark:text-gray-400 z-10"
      style={{ transform: 'translate(0px, 2.5px)' }}
    >
      <li className="me-1">
        <button
          onClick={showEditor}
          aria-current="page"
          className="inline-block px-3 py-2 text-blue-600 bg-light border border-b-light border-light-200 rounded-t-lg active"
        >
          Write
        </button>
      </li>
      <li>
        <button onClick={showPreview} className="inline-block px-3 py-2 border border-b-0 border-light-200 rounded-t-lg">
          Preview
        </button>
      </li>
    </ul>
  );
}
