import { useAppDispatch, useAuthCache } from '../store';
import { authenticated, changeRoom, UserAuthenticationHeader } from '../store/authSlice';

const domain = import.meta.env.BACKEND_URL;
const userURI = import.meta.env.BACKEND_USER;

export const fetchSettings: RequestInit = {
  method: 'GET',
  credentials: 'include',
  redirect: 'follow',
};

export const useAuthentication = () => {
  const dispatch = useAppDispatch();
  const auth = useAuthCache();

  const handleError = (err: any) => {
    console.error(err);
  };

  const login = () => {
    fetch(`${domain}${userURI}/headers`, fetchSettings)
      .then((res) =>
        res
          .json()
          .then((res: UserAuthenticationHeader) => {
            dispatch(
              authenticated({
                username: res.username,
                userID: res.userID,
                sessionID: res.sessionID,
                jwt: res.jwt,
                authenticated: true,
                roomID: res.roomID,
              }),
            );
          })
          .catch(handleError),
      )
      .catch(handleError);
  };

  const newShareRoom = () => {
    fetch(`${domain}${userURI}/share`, { ...fetchSettings, method: 'POST' })
      .then((res) =>
        res
          .json()
          .then((res: { Roomid: string; Sessionid: string }) => {
            // TODO: send to backend current state and make redux accordingly
            dispatch(changeRoom(res.Roomid));
          })
          .catch(handleError),
      )
      .catch(handleError);
  };

  return { login, newShareRoom };
};
